package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.ModelComponent;

/**
 * 模型组件管理Mapper接口
 * 
 * @author hmy
 * @date 2025-07-04
 */
public interface ModelComponentMapper extends BaseMapper<ModelComponent>
{
    /**
     * 查询模型组件管理
     * 
     * @param modelId 模型组件管理主键
     * @return 模型组件管理
     */
    public ModelComponent selectModelComponentByModelId(Long modelId);

    /**
     * 查询模型组件管理列表
     * 
     * @param modelComponent 模型组件管理
     * @return 模型组件管理集合
     */
    public List<ModelComponent> selectModelComponentList(ModelComponent modelComponent);

    /**
     * 新增模型组件管理
     * 
     * @param modelComponent 模型组件管理
     * @return 结果
     */
    public int insertModelComponent(ModelComponent modelComponent);

    /**
     * 修改模型组件管理
     * 
     * @param modelComponent 模型组件管理
     * @return 结果
     */
    public int updateModelComponent(ModelComponent modelComponent);

    /**
     * 删除模型组件管理
     * 
     * @param modelId 模型组件管理主键
     * @return 结果
     */
    public int deleteModelComponentByModelId(Long modelId);

    /**
     * 批量删除模型组件管理
     * 
     * @param modelIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteModelComponentByModelIds(Long[] modelIds);
}
